# coding: utf-8

"""
    Vericred API

    Vericred's API allows you to search for Health Plans that a specific doctor
accepts.

## Getting Started

Visit our [Developer Portal](https://vericred.3scale.net) to
create an account.

Once you have created an account, you can create one Application for
Production and another for our Sandbox (select the appropriate Plan when
you create the Application).

## Authentication

To authenticate, pass the API Key you created in the Developer Portal as
a `Vericred-Api-Key` header.

`curl -H 'Vericred-Api-Key: YOUR_KEY' "https://api.vericred.com/providers?search_term=Foo&zip_code=11215"`

## Versioning

Vericred's API default to the latest version.  However, if you need a specific
version, you can request it with an `Accept-Version` header.

The current version is `v3`.  Previous versions are `v1` and `v2`.

`curl -H 'Vericred-Api-Key: YOUR_KEY' -H 'Accept-Version: v2' "https://api.vericred.com/providers?search_term=Foo&zip_code=11215"`

## Pagination

Endpoints that accept `page` and `per_page` parameters are paginated. They expose
four additional fields that contain data about your position in the response,
namely `Total`, `Per-Page`, `Link`, and `Page` as described in [RFC-5988](https://tools.ietf.org/html/rfc5988).

For example, to display 5 results per page and view the second page of a
`GET` to `/networks`, your final request would be `GET /networks?....page=2&per_page=5`.

## Sideloading

When we return multiple levels of an object graph (e.g. `Provider`s and their `State`s
we sideload the associated data.  In this example, we would provide an Array of
`State`s and a `state_id` for each provider.  This is done primarily to reduce the
payload size since many of the `Provider`s will share a `State`

```
{
  providers: [{ id: 1, state_id: 1}, { id: 2, state_id: 1 }],
  states: [{ id: 1, code: 'NY' }]
}
```

If you need the second level of the object graph, you can just match the
corresponding id.

## Selecting specific data

All endpoints allow you to specify which fields you would like to return.
This allows you to limit the response to contain only the data you need.

For example, let's take a request that returns the following JSON by default

```
{
  provider: {
    id: 1,
    name: 'John',
    phone: '1234567890',
    field_we_dont_care_about: 'value_we_dont_care_about'
  },
  states: [{
    id: 1,
    name: 'New York',
    code: 'NY',
    field_we_dont_care_about: 'value_we_dont_care_about'
  }]
}
```

To limit our results to only return the fields we care about, we specify the
`select` query string parameter for the corresponding fields in the JSON
document.

In this case, we want to select `name` and `phone` from the `provider` key,
so we would add the parameters `select=provider.name,provider.phone`.
We also want the `name` and `code` from the `states` key, so we would
add the parameters `select=states.name,staes.code`.  The id field of
each document is always returned whether or not it is requested.

Our final request would be `GET /providers/12345?select=provider.name,provider.phone,states.name,states.code`

The response would be

```
{
  provider: {
    id: 1,
    name: 'John',
    phone: '1234567890'
  },
  states: [{
    id: 1,
    name: 'New York',
    code: 'NY'
  }]
}
```



    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
"""

from __future__ import absolute_import

import sys
import os
import re

# python 2 and python 3 compatibility library
from six import iteritems

from ..configuration import Configuration
from ..api_client import ApiClient


class DrugsApi(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        config = Configuration()
        if api_client:
            self.api_client = api_client
        else:
            if not config.api_client:
                config.api_client = ApiClient()
            self.api_client = config.api_client

    def get_drug_coverages(self, ndc_package_code, audience, state_code, **kwargs):
        """
        Search for DrugCoverages
        Drug Coverages are the specific tier level, quantity limit, prior authorization and step therapy for a given Drug/Plan combination. This endpoint returns all DrugCoverages for a given Drug

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_drug_coverages(ndc_package_code, audience, state_code, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str ndc_package_code: NDC package code (required)
        :param str audience: Two-character state code (required)
        :param str state_code: Two-character state code (required)
        :return: DrugCoverageResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.get_drug_coverages_with_http_info(ndc_package_code, audience, state_code, **kwargs)
        else:
            (data) = self.get_drug_coverages_with_http_info(ndc_package_code, audience, state_code, **kwargs)
            return data

    def get_drug_coverages_with_http_info(self, ndc_package_code, audience, state_code, **kwargs):
        """
        Search for DrugCoverages
        Drug Coverages are the specific tier level, quantity limit, prior authorization and step therapy for a given Drug/Plan combination. This endpoint returns all DrugCoverages for a given Drug

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_drug_coverages_with_http_info(ndc_package_code, audience, state_code, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str ndc_package_code: NDC package code (required)
        :param str audience: Two-character state code (required)
        :param str state_code: Two-character state code (required)
        :return: DrugCoverageResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['ndc_package_code', 'audience', 'state_code']
        all_params.append('callback')
        all_params.append('_return_http_data_only')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_drug_coverages" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'ndc_package_code' is set
        if ('ndc_package_code' not in params) or (params['ndc_package_code'] is None):
            raise ValueError("Missing the required parameter `ndc_package_code` when calling `get_drug_coverages`")
        # verify the required parameter 'audience' is set
        if ('audience' not in params) or (params['audience'] is None):
            raise ValueError("Missing the required parameter `audience` when calling `get_drug_coverages`")
        # verify the required parameter 'state_code' is set
        if ('state_code' not in params) or (params['state_code'] is None):
            raise ValueError("Missing the required parameter `state_code` when calling `get_drug_coverages`")

        resource_path = '/drug_packages/{ndc_package_code}/coverages'.replace('{format}', 'json')
        path_params = {}
        if 'ndc_package_code' in params:
            path_params['ndc_package_code'] = params['ndc_package_code']

        query_params = {}
        if 'audience' in params:
            query_params['audience'] = params['audience']
        if 'state_code' in params:
            query_params['state_code'] = params['state_code']

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept([])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type([])

        # Authentication setting
        auth_settings = ['Vericred-Api-Key']

        return self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='DrugCoverageResponse',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'),
                                            _return_http_data_only=params.get('_return_http_data_only'))

    def list_drugs(self, search_term, **kwargs):
        """
        Drug Search
        Search for drugs by proprietary name

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.list_drugs(search_term, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str search_term: Full or partial proprietary name of drug (required)
        :return: DrugSearchResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.list_drugs_with_http_info(search_term, **kwargs)
        else:
            (data) = self.list_drugs_with_http_info(search_term, **kwargs)
            return data

    def list_drugs_with_http_info(self, search_term, **kwargs):
        """
        Drug Search
        Search for drugs by proprietary name

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.list_drugs_with_http_info(search_term, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str search_term: Full or partial proprietary name of drug (required)
        :return: DrugSearchResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['search_term']
        all_params.append('callback')
        all_params.append('_return_http_data_only')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_drugs" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'search_term' is set
        if ('search_term' not in params) or (params['search_term'] is None):
            raise ValueError("Missing the required parameter `search_term` when calling `list_drugs`")

        resource_path = '/drugs'.replace('{format}', 'json')
        path_params = {}

        query_params = {}
        if 'search_term' in params:
            query_params['search_term'] = params['search_term']

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['Vericred-Api-Key']

        return self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='DrugSearchResponse',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'),
                                            _return_http_data_only=params.get('_return_http_data_only'))
